// Copyright (C) 2009-2012, Software Development Laboratories, "Fish" (David B. Trout)
//////////////////////////////////////////////////////////////////////////////////////////
// StdAfx.cpp: source file that includes just the standard includes
// <projname>.pch will be the pre-compiled header
// StdAfx.obj will contain the pre-compiled type information
//////////////////////////////////////////////////////////////////////////////////////////
//
//  Change History:
//
//  08/07/09    1.0.0   Fish    Created.
//
//////////////////////////////////////////////////////////////////////////////////////////

#include "StdAfx.h"

//////////////////////////////////////////////////////////////////////////////////////////
// A handy function to have around!

int ErrorMessageBox( HWND hWnd, LPCTSTR pszMessage, LPCTSTR pszTitle, UINT uType )
{
    // Save the error code right away before it changes...

    DWORD dwLastError = GetLastError();

    // Retrieve the system error message for this error code...

    LPTSTR pszLastError;

    FormatMessage
    (
        0
        | FORMAT_MESSAGE_ALLOCATE_BUFFER
        | FORMAT_MESSAGE_FROM_SYSTEM
        | FORMAT_MESSAGE_IGNORE_INSERTS,
        NULL,
        dwLastError,
        MAKELANGID( LANG_NEUTRAL, SUBLANG_DEFAULT ),
        (LPTSTR) &pszLastError,
        0,
        NULL
    );

    // Allocate a buffer large enough to hold our entire error message...

    LPCTSTR  pszFormat  =  _T("%s; rc=%u (0x%08.8X): %s");

    SIZE_T nErrorMessageChars =
        0
        + _tcslen( pszMessage )     //  "%s"
        + 5                         //  "; rc="
        + 10                        //  "%u"
        + 4                         //  " (0x"
        + 8                         //  "%08.8X"
        + 3                         //  "): "
        + _tcslen( pszLastError )   //  "%s"
        + 1                         //  '\0'
        ;

    LPTSTR pszErrorMessage = (LPTSTR) LocalAlloc( LMEM_ZEROINIT, sizeof(TCHAR) * nErrorMessageChars );

    // Format our error message...

    _sntprintf_s
    (
        pszErrorMessage,
        nErrorMessageChars,
        _TRUNCATE,
        pszFormat,              // "%s; rc=%u (0x%08.8X): %s"
        pszMessage,             // (caller's error message)
        dwLastError,            // (system error code)
        dwLastError,            // (same thing in hex)
        pszLastError            // (system error message)
    );

    // Now display the messagebox...

    int rc = SafeMessageBox( hWnd, pszErrorMessage, pszTitle, uType );

    // Free resources before exiting...

    LocalFree( pszLastError );
    LocalFree( pszErrorMessage );

    return rc;      // (whatever button they clicked)
}

//////////////////////////////////////////////////////////////////////////////////////////
// A handy function to have around!

int SafeMessageBox( HWND hWnd, LPCTSTR pszMessage, LPCTSTR pszTitle, UINT uType )
{
    // If we don't have a valid window handle then we must use the
    // 'MB_SERVICE_NOTIFICATION' option to force the messagebox to
    // be displayed on the currently active desktop instead...

    if (0
        || !hWnd
        || !IsWindow( hWnd )
    )
    {
        hWnd = NULL;
        uType |= MB_SERVICE_NOTIFICATION;
    }

    return  ::MessageBox( hWnd, pszMessage, pszTitle, uType );
}

//////////////////////////////////////////////////////////////////////////////////////////
