// Copyright (C) 2009-2015, Software Development Laboratories, "Fish" (David B. Trout)
//////////////////////////////////////////////////////////////////////////////////////////
// StdAfx.h: include file for standard system include files,
// or project specific include files that are used frequently,
// but are otherwise changed relatively infrequently...
//////////////////////////////////////////////////////////////////////////////////////////

#pragma once

//////////////////////////////////////////////////////////////////////////////////////////
// System headers...

#define  WIN32_LEAN_AND_MEAN            // Exclude rarely-used stuff from Windows headers

#define  _WIN32_IE          0x0600      // Internet Exploder 6.0 or greater
#define  _WIN32_WINNT       0x0501      // Windows XP or greater

#include <windows.h>                    // Duh! We're a Windows application!
#include <Shellapi.h>                   // We need to call Shell_NotifyIcon
#include <tchar.h>                      // We need "_T" macro for strings
#include <stdlib.h>                     // We need _countof and _MAX_PATH

//////////////////////////////////////////////////////////////////////////////////////////
// (normally only a level-4 warning!)

#pragma warning( error: 4702 )          // "unreachable code"

//////////////////////////////////////////////////////////////////////////////////////////

#pragma comment                                      \
(                                                    \
    linker,                                          \
    "/manifestdependency:"                           \
    "\""                                             \
        "type='win32'                             "  \
        "name='Microsoft.Windows.Common-Controls' "  \
        "version='6.0.0.0'                        "  \
        "processorArchitecture='*'                "  \
        "publicKeyToken='6595b64144ccf1df'        "  \
        "language='*'                             "  \
    "\""                                             \
)

//////////////////////////////////////////////////////////////////////////////////////////
// Common defines and constants...

#define  TRAYME            "Tray Me!"           // (our system menu command)
#define  TASKBARCREATED    "TaskbarCreated"     // (Windows Explorer restart message name)

typedef  BOOL  WINAPI       HOOKUNHOOKFUNC( HWND hWnd, DWORD dwProcessId );

#define  TRAYICONMSGNAME    "TrayMe_TRAYICONMSGNAME_{674881BE-2558-4a5d-A840-DD3056417F0E}"
#define  UNHIDEMSGNAME      "TrayMe_UNHIDEMSGNAME_{3EA60113-A4D1-4309-8675-0FAA895956EF}"

#define  UNHOOKSLEEP        10                  // Milliseconds to sleep while waiting
#define  UNHOOKTIMEOUT      1000                // Maxmium milliseconds before timing out
#define  MAXTITLELEN        128                 // Maximum window title length

//////////////////////////////////////////////////////////////////////////////////////////
// Debugging support...

#if defined( _DEBUG )

  #define ASSERT(c) \
    do \
    { \
      if (1 \
          && !(c) \
          && _CrtDbgReport( _CRT_ERROR, __FILE__, __LINE__, 0, "Assertion failed!" ) == 1 \
          && IsDebuggerPresent() \
      ) \
        _CrtDbgBreak(); \
    } \
    while (0)

  #define VERIFY(c)  ASSERT(c)

#else // !defined( _DEBUG )

  #define ASSERT     __noop
  #define VERIFY(c)  ((void)(c))

#endif // !defined( _DEBUG )

//////////////////////////////////////////////////////////////////////////////////////////
// TRACEing should always be available even for RETAIL (non-"debug") builds...

#define TRACE      DebugTrace       // (route all TRACE calls to our inlined function)
#define TRACEMAX   1024             // (maximum length that any TRACE message can be)

#include <stdio.h>                  // (need _vsntprintf_s)
#include <crtdbg.h>                 // (need _CrtDbgReport)

inline void __cdecl DebugTrace( LPCTSTR pszFormat, ... )
{
    TCHAR szTraceMessage[ TRACEMAX ];
    va_list vargs; va_start( vargs, pszFormat );
    _vsntprintf_s( szTraceMessage, _countof( szTraceMessage ), _TRUNCATE, pszFormat, vargs );
    OutputDebugString( szTraceMessage );
}

//////////////////////////////////////////////////////////////////////////////////////////
// Handy functions to have around!

extern int ErrorMessageBox( HWND hWnd, LPCTSTR pszMessage, LPCTSTR pszTitle, UINT uType );
extern int SafeMessageBox ( HWND hWnd, LPCTSTR pszMessage, LPCTSTR pszTitle, UINT uType );

//////////////////////////////////////////////////////////////////////////////////////////
